@@ -110,7 +110,9 @@ class Command:
         self.api.feedrate(value)
 
     def set_axis_offset(self, data):
-        self.api.offset(data["name"], x=float(data["x"]), y=float(data["y"]), z=float(data["z"]))
+        command = "G10 L20 " + data["name"] + " X" + data["x"] + " Y" + data["y"] + " Z" + data["z"]
+        self.set_mdi(command)
+        self.set_mode(linuxcnc.MODE_MANUAL, 0.5)
 
     def home_all(self):
         self.set_teleop_enable(0)
